@@ -1,13 +1,14 @@
-# test data is automatically loaded, check ./data-raw/generate_test_data.R
+
+df_visit <- get_df_visit_test_mapped()
 
 test_that("check_df_visit() must fix missing visits and throw a warning", {
-  df_visit_filt <- df_visit_test %>%
+  df_visit_filt <- df_visit %>%
     filter(visit != 3)
 
   # nolint start
-  expect_warning({df_visit_corr <- check_df_visit(df_visit_filt)})
+  expect_warning({df_visit_corr <- check_df_visit(df_visit_filt, event_names = "ae")})
   expect_true(3 %in% df_visit_corr$visit)
-  expect_true(nrow(df_visit_corr) == nrow(df_visit_test))
+  expect_true(nrow(df_visit_corr) == nrow(df_visit))
   # nolint end
 
 })
@@ -15,17 +16,17 @@ test_that("check_df_visit() must fix missing visits and throw a warning", {
 test_that("check_df_visit() must aggregate duplicated visits and throw a warning", {
 
   # nolint start
-  expect_warning({df_visit_corr <- check_df_visit(bind_rows(df_visit_test, df_visit_test))})
-  expect_true(nrow(df_visit_corr) == nrow(df_visit_test))
+  expect_warning({df_visit_corr <- check_df_visit(bind_rows(df_visit, df_visit), event_names = "ae")})
+  expect_true(nrow(df_visit_corr) == nrow(df_visit))
   # nolint end
 
 })
 
 test_that("check_df_visit() must thrown an error when n_ae and visit columns are not numeric", {
   expect_error({
-    df_visit_test %>%
+    df_visit %>%
       mutate_at(vars(n_ae, visit), as.character) %>%
-      check_df_visit()
+      check_df_visit(event_names = "ae")
   },
   regexp = "event number and visit columns must be numeric"
   )
@@ -33,11 +34,11 @@ test_that("check_df_visit() must thrown an error when n_ae and visit columns are
 
 test_that("check_df_visit() must thrown an error when NA's are detected", {
   expect_error({
-    df_visit_test %>%
+    df_visit %>%
       summarise_all(~ NA) %>%
-      bind_rows(df_visit_test) %>%
-      check_df_visit()
+      bind_rows(df_visit) %>%
+      check_df_visit(event_names = "ae")
   },
-  regexp = "NA detected in columns: study_id,site_number,patnum,n_ae,visit"
+  regexp = "NA detected in columns: study_id, site_number, patnum, n_ae, visit"
   )
 })
