@@ -1,8 +1,14 @@
 # test data is automatically loaded, check ./data-raw/generate_test_data.R
 
+df_visit <- get_df_visit_test_mapped()
+
+df_site <- site_aggr(df_visit)
+df_sim_sites <- sim_sites(df_site, df_visit, r = 100)
+df_eval <- eval_sites(df_sim_sites)
+
 
 test_that("eval_sites() must not return a grouped dataframe", {
-  expect_false(is_grouped_df(df_eval_test))
+  expect_false(is_grouped_df(df_eval))
 })
 
 test_that(
@@ -15,14 +21,10 @@ test_that(
            prob_low = NA)
 
 
-  df_sim_sites <- df_sim_sites_test %>%
+  df_sim_sites <- df_sim_sites %>%
     bind_rows(df_na)
 
-  # a new line is created for each site with NA values
-  # this cannot be captured with expect_warning()
-  # https://testthat.r-lib.org/articles/third-edition.html
-  # as of testthat 3.0
-  expect_snapshot(
+  expect_warning(
     df_eval <- eval_sites(df_sim_sites, r_sim_sites = 100)
   )
 
@@ -41,14 +43,22 @@ test_that(
 
 
 test_that("eval_sites() - check column names of returned data frame", {
-
   expect_true(
-    c(
+    ! c(
       "pval_adj",
       "pval_prob_ur",
       "prob_low_adj",
       "prob_low_prob_ur"
-    ) %in% colnames(df_eval_test) %>%
+    ) %in% colnames(df_eval) %>%
       all()
   )
+
+  expect_true(
+    c(
+      "pval",
+      "prob"
+    ) %in% colnames(df_eval) %>%
+      all()
+  )
+
 })
